<?php

define('POSTS_IMAGES__DEFAULT_WIDTH', 497);

class Processor {

    private $source;
    private $target;
    private $thumbnail;

    public function __construct($name, $source) {
        $this->source = $source;
        $imagename = basename($name);
        $thumbname = 'thumb-' . $imagename;
        $options = get_option('posts_images_options');
        $path = $options['path'];
        $year = date('Y');
        $month = date('m');
        $dest = $path . '/' . $year . '/' . $month;
        $this->target =  $dest . '/' . $imagename;
        $this->thumbnail = $dest . '/' . $thumbname;
    }

    private function dummythumb() {
        copy($this->target, $this->thumbnail);
        return false;
    }

    public function process() {
        if (!is_dir(dirname($this->target)) &&
            !mkdir(dirname($this->target), 0777, true))
            return false;
        if (!move_uploaded_file($this->source, $this->target))
            return false;
        $options = get_option('posts_images_options');
        $width = floatval($options['width']);
        if ($width < 1.0)
            return $this->dummythumb();
        $size = getimagesize($this->target);
        if (!$size)
            return $this->dummythumb();
        $w = floatval($size[0]);
        $h = floatval($size[1]);
        $scale = 1.0 / ($w/$width);
        $height = $h * $scale;
        if ($height < 1.0)
            return $this->dummythumb();
        $image = imagecreatefromjpeg($this->target);
        if (!$image)
            return $this->dummythumb();
        $thumb = imagescale($image, intval($width), intval($height));
        if (!$thumb)
            return $this->dummythumb();
        if (!imagejpeg($thumb, $this->thumbnail))
            return $this->dummythumb();
        return true;
    }
}
?>
